Holt-Winters with multiplicative seasonality, the smoothing parameters chosen by the squared error of the one-step forecasts. The series must be positive and cover three cycles.
Value
A model specification, to use with fit_model(),
forecast_model() or backtest().
Examples
fit_model(model_holt_winters(), AirPassengers)$params
#> alpha beta gamma phi sse_relative
#> 0.3000000 0.0200000 0.8000000 1.0000000 0.2195894