The Theta method (Assimakopoulos & Nikolopoulos, 2000), equivalent to simple exponential smoothing with drift, applied to the series seasonally adjusted by classical multiplicative decomposition when it is seasonal.
Value
A model specification, to use with fit_model(),
forecast_model() or backtest().
Examples
forecast_model(model_theta(), AirPassengers, h = 3)
#> Jan Feb Mar
#> 1961 440.0767 428.3829 489.7055